@@ -1,6 +1,9 @@
-static char RcsId[] = "$Header: /segfs/dbase/res/svc/ndbm/RCS/dbm_impexp.cpp,v 6.9 2000/03/15 17:07:52 taurel Rel goetz $";
+static char RcsId[] = "$Header: dbm_impexp.cpp,v 6.10 2001/01/08 11:45:53 goetz Rel $";
+
+/* $Log:	dbm_impexp.cpp,v $
+Revision 6.10  2001/01/08  11:45:53  11:45:53  goetz (Andy Goetz)
+added patch by B.Pedersen to support querying events
 
-/* $Log: dbm_impexp.cpp,v $
  * Revision 6.9  2000/03/15 17:07:52  taurel
  * Change compilation variable from -solaris to sun
  *
