@@ -1,9 +1,12 @@
-static char RcsId[] = "$Header: main_svc.cpp,v 6.10 2001/01/08 11:45:53 goetz Rel $";
-
-/* $Log:	main_svc.cpp,v $
-Revision 6.10  2001/01/08  11:45:53  11:45:53  goetz (Andy Goetz)
-added patch by B.Pedersen to support querying events
+static char RcsId[] = "$Header: /segfs/dbase/res/svc/ndbm/RCS/main_svc.cpp,v 6.11 2001/05/15 14:56:55 goetz Exp $";
 
+/* $Log: main_svc.cpp,v $
+ * Revision 6.11  2001/05/15 14:56:55  goetz
+ * included prototype for gethostname (needed by solaris platforms)
+ *
+ * Revision 6.10  2001/01/08 11:45:53  goetz
+ * added patch by B.Pedersen to support querying events
+ *
  * Revision 6.9  2000/03/15 17:07:48  taurel
  * Change compilation variable from -solaris to sun
  *
@@ -106,7 +109,7 @@ extern "C"
 {
   u_long gettransient(const char *);
   void get_myaddress(struct sockaddr_in *);
-// int gethostname(char *,size_t);
+  int gethostname(char *,size_t);
 }
 
 typedef char * (* DbRpcLocalFunc)(...);
