@@ -1,4 +1,4 @@
-static char RcsId[] = "@(#)$Header: /segfs/dbase/res/clnt/RCS/reconnect_cli.c,v 6.12 2001/01/08 13:29:17 goetz Rel $";
+static char RcsId[] = "@(#)$Header: /segfs/dbase/res/clnt/RCS/reconnect_cli.c,v 6.14 2001/09/12 14:53:02 taurel Rel $";
 
 /*+*******************************************************************
 
@@ -16,9 +16,15 @@ static char RcsId[] = "@(#)$Header: /segfs/dbase/res/clnt/RCS/reconnect_cli.c,v
 
 
  * $Log: reconnect_cli.c,v $
- * Revision 6.12  2001/01/08 13:29:17  goetz
- * added J.Quick's patch to support double arrays for resources
+ * Revision 6.14  2001/09/12 14:53:02  taurel
+ * Add db_exp.cpp file with function to get Tango device name in db_getdevexp call (C++ only)
  *
+ * Revision 6.13  2001/01/23  14:25:12  14:25:12  taurel (E.Taurel)
+ * Remove test on resource length (for String) in the put_resource call
+ * 
+ * Revision 6.12  2001/01/08  13:29:17  13:29:17  goetz (Andy Goetz)
+ * added J.Quick's patch to support double arrays for resources
+ * 
  * Revision 6.11  2001/01/08 11:46:14  goetz
  * added patch by B.Pedersen to support querying events
  *
