@@ -1,4 +1,4 @@
-static char RcsId[] = "@(#)$Header: /segfs/dbase/res/clnt/RCS/update_cli.c,v 6.12 2001/01/08 13:29:17 goetz Rel $";
+static char RcsId[] = "@(#)$Header: /segfs/dbase/res/clnt/RCS/update_cli.c,v 6.14 2001/09/12 14:53:02 taurel Rel $";
 
 /*+*******************************************************************
 
@@ -17,9 +17,15 @@ static char RcsId[] = "@(#)$Header: /segfs/dbase/res/clnt/RCS/update_cli.c,v 6.1
 
 
  * $Log: update_cli.c,v $
- * Revision 6.12  2001/01/08 13:29:17  goetz
- * added J.Quick's patch to support double arrays for resources
+ * Revision 6.14  2001/09/12 14:53:02  taurel
+ * Add db_exp.cpp file with function to get Tango device name in db_getdevexp call (C++ only)
  *
+ * Revision 6.13  2001/01/23  14:25:11  14:25:11  taurel (E.Taurel)
+ * Remove test on resource length (for String) in the put_resource call
+ * 
+ * Revision 6.12  2001/01/08  13:29:17  13:29:17  goetz (Andy Goetz)
+ * added J.Quick's patch to support double arrays for resources
+ * 
  * Revision 6.11  2001/01/08 11:46:14  goetz
  * added patch by B.Pedersen to support querying events
  *
@@ -1164,13 +1170,13 @@ static long check_dev(char *lin,long *p_err_dev,long *p_error)
 
 /* Allocate memory for strok pointers */
 
-	if ((ptr_cp = malloc(strlen(lin) + 1)) == NULL)
+	if ((ptr_cp = (char *)malloc(strlen(lin) + 1)) == NULL)
 	{
 		*p_error = DbErr_ClientMemoryAllocation;
 		return(-1);
 	}
 	
-	if ((ptr = malloc(strlen(lin) + 1)) == NULL)
+	if ((ptr = (char *)malloc(strlen(lin) + 1)) == NULL)
 	{
 		free(ptr_cp);
 		*p_error = DbErr_ClientMemoryAllocation;
