@@ -13,15 +13,45 @@
  Original:	June 1992
 
 
- $Revision: 8.20 $
- $Date: 2001/01/08 13:11:54 $
+ $Revision: 8.30 $
+ $Date: 2001/11/12 09:59:59 $
 
  $Author: goetz $
 
  $Log:	ApiP.h,v $
- * Revision 8.20  2001/01/08  13:11:54  13:11:54  goetz (Andy Goetz)
- * added patch by B.Pedersen to support querying events
+ * Revision 8.30  2001/11/12  09:59:59  09:59:59  goetz (Andy Goetz)
+ * updated C port for Windows 95/98/NT using Visual C++ 6
  * 
+ Revision 8.29  2001/07/26 05:05:08  goetz
+ fixed error in CORBA::is_nil() test
+
+ Revision 8.28  2001/07/25 13:13:15  goetz
+ tango cmd_query in_name and out_name left NULL; desc replaces reason for errors
+
+ Revision 8.27  2001/07/25 13:05:39  goetz
+ added space to dev_error_str() string; test CORBA::is_nil() for tango database
+
+ Revision 8.26  2001/04/10 14:24:34  goetz
+ set timeout on tango devices to 3 seconds
+
+ Revision 8.25  2001/03/20 11:56:38  goetz
+ DevCmdNameList searched before database for commands in tango_api.cpp
+
+ Revision 8.24  2001/03/10 16:38:20  goetz
+ ported tango_api to TANGO 2
+
+ Revision 8.23  2001/02/28 12:26:47  goetz
+ converted TANGO states to TACO states
+
+ Revision 8.22  2001/01/16 10:09:45  goetz
+ applied J.Quick's patch for security; removed stderr from DevServerMain.c
+
+ * Revision 8.21  2001/01/15  11:36:39  11:36:39  goetz (Andy Goetz)
+ * added check for ds == NULL in all dev_ api routines; changed ds__signal prototype
+ * 
+ Revision 8.20  2001/01/08 13:11:54  goetz
+ added patch by B.Pedersen to support querying events
+
  Revision 8.31  2000/07/28 09:59:52  dserver
  BP: added dev_query_event to get event parameters
      -> new data struture  for event list in server
@@ -184,7 +214,7 @@
  */
 #ifdef _IDENT
 static char ApiPh[] =
-"@(#)$Header: ApiP.h,v 8.20 2001/01/08 13:11:54 goetz Rel $";
+"@(#)$Header: ApiP.h,v 8.30 2001/11/12 09:59:59 goetz Rel $";
 #endif /* _IDENT */
 
 
