@@ -1,4 +1,4 @@
-static char RcsId[] = "$Header: OICDevice.C,v 1.2 97/06/30 17:35:07 goetz Exp $";
+static char RcsId[] = "$Header: OICDevice.C,v 5.15 98/01/13 13:38:28 goetz Exp $";
 
 //+**********************************************************************
 //
@@ -17,13 +17,16 @@ static char RcsId[] = "$Header: OICDevice.C,v 1.2 97/06/30 17:35:07 goetz Exp $"
 //
 // Original:	November 1996
 //
-// $Revision: 1.2 $
+// $Revision: 5.15 $
 //
-// $Date: 97/06/30 17:35:07 $
+// $Date: 98/01/13 13:38:28 $
 //
 // $Author: goetz $
 //
 // $Log:	OICDevice.C,v $
+//Revision 5.15  98/01/13  13:38:28  13:38:28  goetz (Andy Goetz)
+//creating version 5.15 so that WDK can create branch 5.15.1
+//
 //Revision 1.2  97/06/30  17:35:07  17:35:07  goetz (Andy Goetz)
 //added MethodFinder
 //
@@ -104,7 +107,7 @@ long OICDevice::ClassInitialise( long *error )
 //
 //-=====================================================================
 
-long OICDevice::GetResources( char *name, long *error )
+long OICDevice::GetResources( char *lname, long *error )
 {
    dev_printdebug(DBG_TRACE,"OICDevice::GetResources() called\n");
 
@@ -128,12 +131,6 @@ long OICDevice::GetResources( char *name, long *error )
 OICDevice::OICDevice (char *devname, DevServerClass devclass, long *error)
           :Device (devname, error)
 {
-   static  Device::DeviceCommandListEntry dev_cmd_list[] = {
-                {DevState, (DeviceMemberFunction)&OICDevice::State, D_VOID_TYPE, D_SHORT_TYPE},
-                {DevStatus, (DeviceMemberFunction)&OICDevice::Status, D_VOID_TYPE, D_STRING_TYPE},
-                                              };
-   static long no_commands = sizeof(dev_cmd_list)/
-			     sizeof(DeviceCommandListEntry);
    DevServerClass oicclass;
    int i;
 
@@ -152,6 +149,8 @@ OICDevice::OICDevice (char *devname, DevServerClass devclass, long *error)
       return;
    }
 
+   printf("OICDevice::OICDevice() returned from ds__create and all's fine !\n");
+
    oicclass = this->ds->devserver.class_pointer;
 
 //
@@ -196,12 +195,26 @@ OICDevice::OICDevice (char *devname, DevServerClass devclass, long *error)
      this->commands_list[i].argin_type = oicclass->devserver_class.commands_list[i].argin_type;
      this->commands_list[i].argout_type = oicclass->devserver_class.commands_list[i].argout_type;
      this->commands_list[i].min_access = oicclass->devserver_class.commands_list[i].min_access;
-/*
      printf("OICDevice::OICDevice() command(%d) cmd=%d argin_type=%d argout_type=%d min_access=%d\n",
              i,this->commands_list[i].cmd,this->commands_list[i].argin_type,
              this->commands_list[i].argout_type,this->commands_list[i].min_access);
- */
    }
+/* same for the new event list */
+   this->n_events = oicclass->devserver_class.n_events;
+//
+// now copy the list of events and their input and output argument
+// types to the DeviceEventListEntry. This code makes the assumption
+// that one can cast and copy a DevEventListEntry* to a Device::Device
+// EventListEntry*
+//
+//   this->events_list = (Device::DeviceEventListEntry*)oicclass->devserver_class.events_list;
+//
+   this->events_list = (Device::DeviceEventListEntry*)malloc(this->n_events*sizeof(DeviceEventListEntry));
+   for (i=0; i<this->n_events; i++)
+   {
+       this->events_list[i].event = oicclass->devserver_class.events_list[i].event;
+       this->events_list[i].argout_type = oicclass->devserver_class.events_list[i].argout_type;
+   } 
 }
 
 //+=====================================================================
@@ -228,8 +241,6 @@ OICDevice::OICDevice (char *devname, DevServerClass devclass, long *error)
 long OICDevice::Command (long cmd, void* argin, long argin_type,
                       void* argout, long argout_type, long *error)
 {
-   int i;
-   DeviceMemberFunction member_fn;
 
    dev_printdebug(DBG_TRACE,"OICDevice::Command() called, cmd = %d\n",cmd);
 
@@ -347,16 +358,16 @@ long OICDevice::StateMachine(long cmd, long *error)
 
 long OICDevice::State(void *vargin, void *vargout, long *error)
 {
-   static short *state;
+   static short *pstate;
    *error = DS_OK;
 
    dev_printdebug(DBG_TRACE,"OICDevice::State() called\n");
 
-   state = (short*)vargout;
+   pstate = (short*)vargout;
 //
 // code to implement the DevState command here
 //
-   *state = (short)this->ds->devserver.state;
+   *pstate = (short)this->ds->devserver.state;
 
    return(DS_OK);
 }
