@@ -1,4 +1,4 @@
-static char RcsId[] = "@(#)$Header: asyn_api.c,v 8.20 2001/01/08 12:05:09 goetz Rel $";
+static char RcsId[] = "@(#)$Header: asyn_api.c,v 8.30 2001/11/12 09:59:58 goetz Rel $";
 /*+*******************************************************************
 
  File       :	asyn_api.c
@@ -25,15 +25,45 @@ static char RcsId[] = "@(#)$Header: asyn_api.c,v 8.20 2001/01/08 12:05:09 goetz
 
  Original   :	January 1997
 
- $Revision: 8.20 $
- $Date: 2001/01/08 12:05:09 $
+ $Revision: 8.30 $
+ $Date: 2001/11/12 09:59:58 $
 
  $Author: goetz $
 
  $Log:	asyn_api.c,v $
- * Revision 8.20  2001/01/08  12:05:09  12:05:09  goetz (Andy Goetz)
- * added patch by B.Pedersen to support querying events
+ * Revision 8.30  2001/11/12  09:59:58  09:59:58  goetz (Andy Goetz)
+ * updated C port for Windows 95/98/NT using Visual C++ 6
  * 
+ Revision 8.29  2001/07/26 05:05:07  goetz
+ fixed error in CORBA::is_nil() test
+
+ Revision 8.28  2001/07/25 13:13:14  goetz
+ tango cmd_query in_name and out_name left NULL; desc replaces reason for errors
+
+ Revision 8.27  2001/07/25 13:05:38  goetz
+ added space to dev_error_str() string; test CORBA::is_nil() for tango database
+
+ Revision 8.26  2001/04/10 14:24:33  goetz
+ set timeout on tango devices to 3 seconds
+
+ Revision 8.25  2001/03/20 11:56:37  goetz
+ DevCmdNameList searched before database for commands in tango_api.cpp
+
+ Revision 8.24  2001/03/10 16:38:18  goetz
+ ported tango_api to TANGO 2
+
+ Revision 8.23  2001/02/28 12:26:46  goetz
+ converted TANGO states to TACO states
+
+ Revision 8.22  2001/01/16 10:09:44  goetz
+ applied J.Quick's patch for security; removed stderr from DevServerMain.c
+
+ * Revision 8.21  2001/01/15  11:36:36  11:36:36  goetz (Andy Goetz)
+ * added check for ds == NULL in all dev_ api routines; changed ds__signal prototype
+ * 
+ Revision 8.20  2001/01/08 12:05:09  goetz
+ added patch by B.Pedersen to support querying events
+
  Revision 8.19  2000/12/11 12:06:36  goetz
  fixed bugs with TANGO interface returning unsigned values and states
 
@@ -804,8 +834,10 @@ static void _WINAPI devserver_prog_5 (struct svc_req *rqstp, SVCXPRT *transp)
 	long error;
 /*	long status;*/
 	static struct timeval timenow;
+#ifndef WIN32
 	static struct timezone tz;
-#ifdef vxworks
+#endif /* !WIN32 */
+#if defined (vxworks) || (WIN32)
 	time_t tea_time;
 #endif /* vxworks */
 	enum clnt_stat clnt_stat;
@@ -1112,15 +1144,16 @@ static void _WINAPI devserver_prog_5 (struct svc_req *rqstp, SVCXPRT *transp)
  * can identify the reply
  *
  * return time command was executed by server to client tagged on
- * (simulate gettimeofday() with time() on VxWorks)
+ * (simulate gettimeofday() with time() on Windows and VxWorks)
  */
 
-#ifndef vxworks
-			gettimeofday(&timenow,&tz);
-#else
+#if defined (vxworks) || (WIN32)
 			time(&tea_time);
 			timenow.tv_sec = tea_time;
 			timenow.tv_usec = 0;
+#else
+
+			gettimeofday(&timenow,&tz);
 #endif /* !vxworks */
 			iarg = 0;
 			vararg[iarg].argument_type	= D_ULONG_TYPE;
@@ -1346,18 +1379,18 @@ long _DLLFunc asynch_rpc_register(long *error)
  * to the client and to catch SIGINT, SIGQUIT and SIGTERM and unregister 
  * the asynchronous service from the portmapper - for UNIX and OS9
  */
+#ifndef WIN32
 			(void) signal(SIGINT, main_signal_handler);
 			(void) signal(SIGQUIT, main_signal_handler);
 			(void) signal(SIGTERM, main_signal_handler);
-
 			(void) signal(SIGHUP, main_signal_handler);
 			(void) signal(SIGPIPE, main_signal_handler);
-#if defined (_NT)
+#else
 			(void) signal(SIGINT, main_signal_handler);
 			(void) signal(SIGABRT, main_signal_handler);
 			(void) signal(SIGTERM, main_signal_handler);
 			(void) signal(SIGBREAK, main_signal_handler);
-#endif /* _NT */
+#endif /* !WIN32 */
 
 		}
 
@@ -1537,7 +1570,7 @@ long asynch_server_import(devserver ds, long *error)
 #if !defined (_NT)
                         close (tcp_socket);
 #else
-                        close_socket (tcp_socket);
+                        closesocket (tcp_socket);
 #endif /* _NT */
 			clnt_destroy(asynch_clnt_tcp);
 			return(DS_NOTOK);
@@ -1848,7 +1881,12 @@ long _DLLFunc dev_synch(struct timeval *timeout, long *error)
 #endif
 			{
 #ifndef _UCC
+#ifndef WIN32
 				case -1 : if (errno == EINTR)
+#else
+				case SOCKET_ERROR : if (WSAGetLastError() == WSAEINTR)
+#endif /* WIN32 */
+
 #else
                         	case -1 : if ((errno == EINTR) || (errno == EOS_SIGNAL))
 #endif
