@@ -1,4 +1,4 @@
- char RcsId[] = "@(#)$Header: dev_api.c,v 8.20 2001/01/08 12:05:09 goetz Rel $";
+ char RcsId[] = "@(#)$Header: dev_api.c,v 8.30 2001/11/12 09:59:58 goetz Rel $";
 /*+*******************************************************************
 
  File       :	dev_api.c
@@ -14,15 +14,45 @@
 
  Original   :	January 1991
 
- $Revision: 8.20 $
- $Date: 2001/01/08 12:05:09 $
+ $Revision: 8.30 $
+ $Date: 2001/11/12 09:59:58 $
 
  $Author: goetz $
 
  $Log:	dev_api.c,v $
- * Revision 8.20  2001/01/08  12:05:09  12:05:09  goetz (Andy Goetz)
- * added patch by B.Pedersen to support querying events
+ * Revision 8.30  2001/11/12  09:59:58  09:59:58  goetz (Andy Goetz)
+ * updated C port for Windows 95/98/NT using Visual C++ 6
  * 
+ Revision 8.29  2001/07/26 05:05:07  goetz
+ fixed error in CORBA::is_nil() test
+
+ Revision 8.28  2001/07/25 13:13:14  goetz
+ tango cmd_query in_name and out_name left NULL; desc replaces reason for errors
+
+ Revision 8.27  2001/07/25 13:05:38  goetz
+ added space to dev_error_str() string; test CORBA::is_nil() for tango database
+
+ Revision 8.26  2001/04/10 14:24:33  goetz
+ set timeout on tango devices to 3 seconds
+
+ Revision 8.25  2001/03/20 11:56:37  goetz
+ DevCmdNameList searched before database for commands in tango_api.cpp
+
+ Revision 8.24  2001/03/10 16:38:18  goetz
+ ported tango_api to TANGO 2
+
+ Revision 8.23  2001/02/28 12:26:46  goetz
+ converted TANGO states to TACO states
+
+ Revision 8.22  2001/01/16 10:09:44  goetz
+ applied J.Quick's patch for security; removed stderr from DevServerMain.c
+
+ * Revision 8.21  2001/01/15  11:36:36  11:36:36  goetz (Andy Goetz)
+ * added check for ds == NULL in all dev_ api routines; changed ds__signal prototype
+ * 
+ Revision 8.20  2001/01/08 12:05:09  goetz
+ added patch by B.Pedersen to support querying events
+
  Revision 8.19  2000/12/11 12:06:33  goetz
  fixed bugs with TANGO interface returning unsigned values and states
 
@@ -95,7 +125,7 @@
 #include <DevErrors.h>
 #include <API_xdr_vers3.h>
 
-#if !defined _NT
+#if !defined WIN32
 #if ( (defined OSK) || (defined _OSK))
 #include <inet/socket.h>
 #include <inet/netdb.h>
@@ -121,7 +151,7 @@
 #include <linux/posix_types.h>
 #endif /* linux */
 #endif /* OSK || _OSK */
-#endif /* _NT */
+#endif /* WIN32 */
 
 #include <errno.h>
 
@@ -250,7 +280,7 @@ long _DLLFunc dev_import (char *dev_name, long access,
 #endif /* EBUG */
 
 #ifdef TANGO
-	if (strncmp(dev_name,"tango:",6) == 0)
+	if (strncasecmp(dev_name,"tango:",6) == 0)
 	{
 		status = tango_dev_import(dev_name+6,access, ds_ptr, error);
 		printf("dev_import(): tango_dev_import(%s) returned %d\n",dev_name,status);
@@ -639,6 +669,16 @@ long _DLLFunc dev_import (char *dev_name, long access,
 			clnt_control (clnt, CLSET_RETRY_TIMEOUT, (char *) &retry_timeout);
 			clnt_control (clnt, CLSET_TIMEOUT, (char *) &timeout);
 		}
+
+			/*
+	       * initialise the administration structure for the RPC connection
+	       */
+
+		svr_conns[n_svr_conn].clnt        = clnt;
+		svr_conns[n_svr_conn].vers_number = vers_number;
+		svr_conns[n_svr_conn].udp_clnt = clnt;
+		svr_conns[n_svr_conn].tcp_clnt = NULL;
+		svr_conns[n_svr_conn].asynch_clnt = NULL;
 	}
 
 	else
@@ -801,20 +841,7 @@ long _DLLFunc dev_import (char *dev_name, long access,
  */
 			memset ((char *)*ds_ptr, 0, sizeof (devserver));
 
-			/*
-	       * initialise the administration structure for the RPC connection
-	       * if this is the first device connected.
-	       */
-
-			if ( svr_conns[n_svr_conn].no_conns == 0)
-			{
-				svr_conns[n_svr_conn].clnt        = clnt;
-				svr_conns[n_svr_conn].vers_number = vers_number;
-				svr_conns[n_svr_conn].udp_clnt    = clnt;
-				svr_conns[n_svr_conn].tcp_clnt    = NULL;
-				svr_conns[n_svr_conn].asynch_clnt = NULL;
-			}
-			else
+			if ( svr_conns[n_svr_conn].no_conns != 0)
 			{
 				/*
 		  * If the connection is marked as bad connection
@@ -971,6 +998,11 @@ long _DLLFunc dev_putget (devserver ds, long cmd,DevArgument argin,
 	dev_printdebug (DBG_TRACE | DBG_API,
 	    "\ndev_putget() : entering routine\n");
 #endif /* EBUG */
+	if (ds == NULL)
+	{
+		*error = DevErr_DeviceNotImportedYet;
+		return(DS_NOTOK);
+	}
 /*
  * make sure dynamic error string points to nothing
  */
@@ -1172,6 +1204,11 @@ long _DLLFunc dev_put (devserver ds, long cmd,DevArgument argin,
 	dev_printdebug (DBG_TRACE | DBG_API,
 	    "\ndev_put() : entering routine\n");
 #endif /* EBUG */
+	if (ds == NULL)
+	{
+		*error = DevErr_DeviceNotImportedYet;
+		return(DS_NOTOK);
+	}
 /*
  * make sure dynamic error string points to nothing
  */
@@ -1369,6 +1406,11 @@ long _DLLFunc dev_free (devserver ds, long *error)
 	    "dev_free() :  ds_id = %d\n",ds->ds_id);
 #endif /* EBUG */
 
+	if (ds == NULL)
+	{
+		*error = DevErr_DeviceNotImportedYet;
+		return(DS_NOTOK);
+	}
 #ifdef TANGO
 	if (ds->rpc_protocol == D_IIOP)
 	{
@@ -1523,6 +1565,21 @@ long _DLLFunc dev_free (devserver ds, long *error)
 		}
 	}
 
+	/*
+	 * Decrease the counter of single user accesses
+	 * if a single user access was freed. If it was the last
+	 * single user access for the connection reinstall the initial
+	 * protocol.
+	 *
+	 * Free the security key for the connection.
+	 */
+
+	if ( nethost->config_flags.security == True )
+	{
+		sec_free_tcp_connection (ds, &svr_conns[ds->no_svr_conn]);
+		free_sec_key (ds);
+	}
+
 
 
 	/*
@@ -1546,11 +1603,11 @@ long _DLLFunc dev_free (devserver ds, long *error)
 	    */
 		if (svr_conns[ds->no_svr_conn].tcp_clnt != NULL)
 		{
-#if !defined (_NT)
+#if !defined (WIN32)
 			close (svr_conns[ds->no_svr_conn].tcp_socket);
 #else
-			close_socket (svr_conns[ds->no_svr_conn].tcp_socket);
-#endif /* _NT */
+			closesocket (svr_conns[ds->no_svr_conn].tcp_socket);
+#endif /* WIN32 */
 			clnt_destroy (svr_conns[ds->no_svr_conn].tcp_clnt);
 		}
 	   /*
@@ -1612,19 +1669,19 @@ long _DLLFunc dev_free (devserver ds, long *error)
 			errno = 0;
 /*
 			shutdown(svr_conns[ds->no_svr_conn].asynch_listen_tcp_socket,2);
-#if !defined (_NT)
+#if !defined (WIN32)
                 	close (svr_conns[ds->no_svr_conn].asynch_listen_tcp_socket);
 #else
                 	close_socket (svr_conns[ds->no_svr_conn].asynch_listen_tcp_socket);
-#endif  * _NT * 
+#endif  * WIN32 * 
  */
 /* DON'T - 26/3/98
 			shutdown(svr_conns[ds->no_svr_conn].asynch_callback_tcp_socket,2);
-#if !defined (_NT)
+#if !defined (WIN32)
                 	close (svr_conns[ds->no_svr_conn].asynch_callback_tcp_socket);
 #else
                 	close_socket (svr_conns[ds->no_svr_conn].asynch_callback_tcp_socket);
-#endif * _NT *
+#endif * WIN32 *
 #ifdef EBUG
 			dev_printdebug ( DBG_ASYNCH,
 			"dev_free(): closed client socket out=%d (errno=%d)\n",
@@ -1649,21 +1706,6 @@ long _DLLFunc dev_free (devserver ds, long *error)
 		    (char *) &svr_conns[ds->no_svr_conn].rpc_timeout);
 	}
 
-	/*
-	 * Decrease the counter of single user accesses
-	 * if a single user access was freed. If it was the last
-	 * single user access for the connection reinstall the initial
-	 * protocol.
-	 *
-	 * Free the security key for the connection.
-	 */
-
-	if ( nethost->config_flags.security == True )
-	{
-		sec_free_tcp_connection (ds, &svr_conns[ds->no_svr_conn]);
-		free_sec_key (ds);
-	}
-
 	/*
 	 * Free the variable arguments in the dev_free_out
 	 * structure, coming from the server. 
@@ -2107,11 +2149,11 @@ long  check_rpc_connection (devserver ds, long *error)
                         * Set version number to 1 and recreate the
                         * client handle.
                         */
-#if !defined (_NT)
+#if !defined (WIN32)
                                                 close (tcp_socket);
 #else
                                                 closesocket (tcp_socket);
-#endif /* _NT */
+#endif /* WIN32 */
 						tcp_socket = RPC_ANYSOCK;
 
 						vers_number = DEVSERVER_VERS;
@@ -2140,11 +2182,11 @@ long  check_rpc_connection (devserver ds, long *error)
          		*  if tcp protocol was used, 
          		*  close the old socket first.
          		*/
-#if !defined (_NT)
+#if !defined (WIN32)
                			close (svr_conns[ds->no_svr_conn].tcp_socket);
 #else
               			closesocket (svr_conns[ds->no_svr_conn].tcp_socket);
-#endif /* _NT */
+#endif /* WIN32 */
 
 	 			clnt_destroy(svr_conns[ds->no_svr_conn].tcp_clnt);
 				svr_conns[ds->no_svr_conn].tcp_clnt = NULL;
@@ -2158,13 +2200,13 @@ long  check_rpc_connection (devserver ds, long *error)
 			if (svr_conns[ds->no_svr_conn].asynch_clnt != NULL)
 			{
 /*
-#if !defined (_NT)
+#if !defined (WIN32)
                			close (svr_conns[ds->no_svr_conn].asynch_listen_tcp_socket);
                			close (svr_conns[ds->no_svr_conn].asynch_callback_tcp_socket);
 #else
               			closesocket (svr_conns[ds->no_svr_conn].asynch_listen_tcp_socket);
               			closesocket (svr_conns[ds->no_svr_conn].asynch_callback_tcp_socket);
-#endif * _NT *
+#endif * WIN32 *
  */
 				clnt_destroy (svr_conns[ds->no_svr_conn].asynch_clnt);
 				svr_conns[ds->no_svr_conn].asynch_clnt = NULL;
@@ -2243,11 +2285,11 @@ long  check_rpc_connection (devserver ds, long *error)
 			{
 				if (svr_conns[ds->no_svr_conn].rpc_protocol == D_TCP)
 				{
-#if !defined (_NT)
+#if !defined (WIN32)
 					close(tcp_socket);
 #else
-					close_socket(tcp_socket);
-#endif /* _NT */
+					closesocket(tcp_socket);
+#endif /* WIN32 */
 				}
 				clnt_destroy(clnt);
 				free(new_ds);
@@ -2291,11 +2333,11 @@ long  check_rpc_connection (devserver ds, long *error)
 			{
 				if (svr_conns[no_svr_conn].rpc_protocol == D_TCP)
 				{
-#if !defined (_NT)
+#if !defined (WIN32)
 					close(tcp_socket);
 #else
-					close_socket(tcp_socket);
-#endif /* _NT */
+					closesocket(tcp_socket);
+#endif /* WIN32 */
 				}
 				clnt_destroy(clnt);
 				
@@ -2370,11 +2412,11 @@ long  check_rpc_connection (devserver ds, long *error)
 	         */
 			if (svr_conns[ds->no_svr_conn].rpc_protocol == D_TCP)
 			{
-#if !defined (_NT)
+#if !defined (WIN32)
                                        close (tcp_socket);
 #else
                                        closesocket (tcp_socket);
-#endif /* _NT */
+#endif /* WIN32 */
 			}
 
 			clnt_destroy (clnt);
@@ -2658,7 +2700,7 @@ long rpc_check_host (char *host_name, long *error)
 #if defined (sun) || defined (lynx) || defined (linux) || defined (irix)
 	ioctl (s, FIONBIO, &nb);
 
-#elif defined (_NT)
+#elif defined (WIN32)
 	ioctlsocket (s, FIONBIO, (u_long *)&nb);
 #else
 	ioctl (s, FIOSNBIO, &nb);
@@ -2667,11 +2709,11 @@ long rpc_check_host (char *host_name, long *error)
 	/*
 	 * try to connect to the remote host.
 	 */
-#if defined (_NT) || defined (linux) || defined (solaris) || defined (_XOPEN_SOURCE_EXTENDED)
+#if defined (WIN32) || defined (linux) || defined (solaris) || defined (_XOPEN_SOURCE_EXTENDED)
 	connect (s,(struct sockaddr *)&peeraddr_in, sizeof(struct sockaddr_in));
 #else
 	connect (s, (void *) &peeraddr_in, sizeof(struct sockaddr_in));
-#endif /* _NT || linux || solaris */
+#endif /* WIN32 || linux || solaris */
 
 	/*
 	 *  select the socket and wait until the connection is 
@@ -2705,11 +2747,11 @@ long rpc_check_host (char *host_name, long *error)
 		dev_printerror (SEND, "%s",
 		    "rpc_check_host: select on socket descriptor failed" );
 		*error = DevErr_CannotConnectToHost;
-#if !defined (_NT)
+#if !defined (WIN32)
                 close (s);
 #else
                 closesocket (s);
-#endif /* _NT */
+#endif /* WIN32 */
 		return (DS_NOTOK);
 	}
 
@@ -2720,19 +2762,19 @@ long rpc_check_host (char *host_name, long *error)
 	if ( FD_ISSET (s, &writemask) == FALSE)
 	{
 		*error = DevErr_CannotConnectToHost;
-#if !defined (_NT)
+#if !defined (WIN32)
                 close (s);
 #else
                 closesocket (s);
-#endif /* _NT */
+#endif /* WIN32 */
 		return (DS_NOTOK);
 	}
 
-#if !defined (_NT)
+#if !defined (WIN32)
 	close (s);
 #else
-	close_socket(s);
-#endif /* _NT */
+	closesocket(s);
+#endif /* WIN32 */
 #endif /* (! OSK) && (! _OSK) */
 
 	return (DS_OK);
@@ -3298,6 +3340,11 @@ long _DLLFunc dev_rpc_protocol (devserver ds, long protocol, long *error)
 
 	*error = 0;
 
+	if (ds == NULL)
+	{
+		*error = DevErr_DeviceNotImportedYet;
+		return(DS_NOTOK);
+	}
 #ifdef TANGO
 	if (ds->rpc_protocol == D_IIOP)
 	{
@@ -3426,11 +3473,11 @@ long _DLLFunc dev_rpc_protocol (devserver ds, long protocol, long *error)
  * DO NOT close the TCP connection - keep it for reuse, it will be closed
  * by dev_free() or check_rpc_connection()
  *
-#if !defined (_NT)
+#if !defined (WIN32)
  *              close (svr_conns[ds->no_svr_conn].tcp_socket);
 #else
  *              closesocket (svr_conns[ds->no_svr_conn].tcp_socket);
-#endif  * _NT * 
+#endif  * WIN32 * 
  *
  *		clnt_destroy (svr_conns[ds->no_svr_conn].clnt);
  */
