@@ -1,5 +1,5 @@
 static char RcsId[] = 
-"@(#)$Header: gen_api.c,v 8.20 2001/01/08 12:05:09 goetz Rel $";
+"@(#)$Header: gen_api.c,v 8.30 2001/11/12 09:59:58 goetz Rel $";
 /*+*******************************************************************
 
  File       :	gen_api.c
@@ -13,15 +13,45 @@ static char RcsId[] =
 
  Original   :	January 1991
 
- $Revision: 8.20 $
- $Date: 2001/01/08 12:05:09 $
+ $Revision: 8.30 $
+ $Date: 2001/11/12 09:59:58 $
 
  $Author: goetz $
 
  $Log:	gen_api.c,v $
- * Revision 8.20  2001/01/08  12:05:09  12:05:09  goetz (Andy Goetz)
- * added patch by B.Pedersen to support querying events
+ * Revision 8.30  2001/11/12  09:59:58  09:59:58  goetz (Andy Goetz)
+ * updated C port for Windows 95/98/NT using Visual C++ 6
  * 
+ Revision 8.29  2001/07/26 05:05:07  goetz
+ fixed error in CORBA::is_nil() test
+
+ Revision 8.28  2001/07/25 13:13:14  goetz
+ tango cmd_query in_name and out_name left NULL; desc replaces reason for errors
+
+ Revision 8.27  2001/07/25 13:05:38  goetz
+ added space to dev_error_str() string; test CORBA::is_nil() for tango database
+
+ Revision 8.26  2001/04/10 14:24:33  goetz
+ set timeout on tango devices to 3 seconds
+
+ Revision 8.25  2001/03/20 11:56:37  goetz
+ DevCmdNameList searched before database for commands in tango_api.cpp
+
+ Revision 8.24  2001/03/10 16:38:18  goetz
+ ported tango_api to TANGO 2
+
+ Revision 8.23  2001/02/28 12:26:46  goetz
+ converted TANGO states to TACO states
+
+ Revision 8.22  2001/01/16 10:09:44  goetz
+ applied J.Quick's patch for security; removed stderr from DevServerMain.c
+
+ * Revision 8.21  2001/01/15  11:36:36  11:36:36  goetz (Andy Goetz)
+ * added check for ds == NULL in all dev_ api routines; changed ds__signal prototype
+ * 
+ Revision 8.20  2001/01/08 12:05:09  goetz
+ added patch by B.Pedersen to support querying events
+
  Revision 8.19  2000/12/11 12:06:32  goetz
  fixed bugs with TANGO interface returning unsigned values and states
 
@@ -353,7 +383,7 @@ _DLLFunc void dev_printerror (DevShort mode, char *fmt, ...)
 			char msg [1024];
 			sprintf ( msg, "\n\n%s\n", 
 			    message_buffer[ERROR_TYPE].messages);
-			conout(msg);
+			PRINTF(msg); //conout(msg);
 #else
 			printf ( "\n\n%s\n", 
 			    message_buffer[ERROR_TYPE].messages);
@@ -424,7 +454,7 @@ _DLLFunc void dev_printerror (DevShort mode,char *fmt, char *str)
 			char msg[1024];
 			sprintf ( msg, "\n\n%s\n", 
 			    message_buffer[ERROR_TYPE].messages);
-			conout(msrg);
+			PRINTF(msg); //conout(msrg);
 #else
 			printf ( "\n\n%s\n", 
 			    message_buffer[ERROR_TYPE].messages);
@@ -565,7 +595,7 @@ void _DLLFunc dev_printdebug (long debug_bits, char *fmt, ...)
 			else
 			{
 #ifdef _NT
-				conout( debug_string );
+				PRINTF(debug_string); //conout( debug_string );
 #else
 				printf ( debug_string );
 #endif
@@ -638,7 +668,7 @@ void dev_printdebug (long debug_bits,char *fmt, char *str)
 			else
 			{
 #ifdef _NT
-				conout ( debug_string );
+				PRINTF(debug_string); //conout ( debug_string );
 #else
 				printf ( debug_string );
 #endif
@@ -725,7 +755,7 @@ _DLLFunc void dev_printdiag (DevShort mode, char *fmt, ...)
 #ifdef _NT
 			char msg[1024];
 			sprintf (msg,"%s", message_buffer[DIAG_TYPE].messages);
-			conout(msg);
+			PRINTF(msg); //conout(msg);
 #else
 			printf ("%s", message_buffer[DIAG_TYPE].messages);
 #endif
@@ -801,7 +831,7 @@ void dev_printdiag (DevShort mode,char *fmt,char *str)
 #ifdef _NT
 			char msg[1024];
 			sprintf (masg,"%s", message_buffer[DIAG_TYPE].messages);
-			conout(msg);
+			PRINTF(msg); //conout(msg);
 #else
 			printf ("%s", message_buffer[DIAG_TYPE].messages);
 #endif
@@ -858,7 +888,7 @@ static void msg_write (_Int msg_type, char *msg_string)
 		if ( (message_buffer[msg_type].messages = (char *)malloc (len)) == NULL )
 		{
 #ifdef _NT
-			conout("msg_write() : Insufficient memory for allocation !");
+			PRINTF("msg_write() : Insufficient memory for allocation !");
 #else
 			printf ("msg_write() : Insufficient memory for allocation !");
 #endif
@@ -893,10 +923,10 @@ static void msg_write (_Int msg_type, char *msg_string)
 #ifdef _NT
 				{
 				char msg[1024];
-				conout("msg_write() : Insufficient memory for reallocation !");
+				PRINTF("msg_write() : Insufficient memory for reallocation !");
 				sprintf(msg,"message_buffer contents :\n%s",
 				    message_buffer[msg_type].messages );
-				conout(msg);
+				PRINTF(msg);
 				}
 #else
 				printf("msg_write() : Insufficient memory for reallocation !");
@@ -970,10 +1000,10 @@ static void msg_send (_Int msg_type)
 #ifdef _NT
 			{
 			char msg[1024];
-			conout(clnt_sperror (msg_info.conf->clnt,"msg_send()"));
+			PRINTF(clnt_sperror (msg_info.conf->clnt,"msg_send()"));
 			sprintf(msg, "message_buffer contents :\n%s",
 			    message_buffer[msg_type].messages );
-			conout(msg);
+			PRINTF(msg);
 			}
 #else
 			clnt_perror (msg_info.conf->clnt,"msg_send()");
@@ -1006,10 +1036,10 @@ static void msg_send (_Int msg_type)
 				{
 				char msg[1024];
 				sprintf (msg,"Message Server : error number %d",msg_out.error);
-				conout(msg);
+				PRINTF(msg);
 				sprintf (msg,"message_buffer contents :\n%s",
 				    message_buffer[msg_type].messages );
-				conout(msg);
+				PRINTF(msg);
 				}
 #else
 				printf ("Message Server : error number %d",msg_out.error);
@@ -1971,8 +2001,8 @@ static char *get_error_string (long error)
  */
         if ( error < 0 )
         {
-		error_str = (char*)malloc(strlen(time_stamp)+strlen(no_error_mess)+2);
-                sprintf ( error_str, "%s %s", time_stamp, no_error_mess );
+		error_str = (char*)malloc(strlen(time_stamp)+strlen(no_error_mess)+3);
+                sprintf ( error_str, "%s  %s", time_stamp, no_error_mess );
                 /*return (DS_WARNING);*/
                 return (error_str);
         }
@@ -2000,8 +2030,8 @@ static char *get_error_string (long error)
 			if ((_Int)(DevErr_List[i].dev_errno) == (_Int)error)
 			{
 				error_str = (char*)malloc(strlen(time_stamp)+
-					strlen(DevErr_List[i].message)+2);
-				sprintf ( error_str, "%s %s", time_stamp, 
+					strlen(DevErr_List[i].message)+3);
+				sprintf ( error_str, "%s  %s", time_stamp, 
 				    DevErr_List[i].message );
 				/*return (DS_OK);*/
 				return (error_str);
@@ -2015,8 +2045,8 @@ static char *get_error_string (long error)
  */
 	if (dev_error_string != NULL)
 	{
-		error_str = (char*)malloc(strlen(time_stamp)+strlen(dev_error_string)+2);
-		sprintf ( error_str, "%s %s", time_stamp, dev_error_string );
+		error_str = (char*)malloc(strlen(time_stamp)+strlen(dev_error_string)+3);
+		sprintf ( error_str, "%s  %s", time_stamp, dev_error_string );
 		error_str[strlen(error_str)] = 0;
 		/*return (DS_OK);*/
 		return (error_str);
@@ -2061,16 +2091,16 @@ static char *get_error_string (long error)
 			if ((_Int)(DevErr_List[i].dev_errno) == (_Int)db_error)
 			{
 				error_str = (char*)malloc(strlen(time_stamp)+
-					strlen(DevErr_List[i].message)+2);
-				sprintf ( error_str, "%s %s", time_stamp, 
+					strlen(DevErr_List[i].message)+3);
+				sprintf ( error_str, "%s  %s", time_stamp, 
 				    DevErr_List[i].message );
 				/*return (DS_NOTOK);*/
 				return (error_str);
 			}
 		}
 
-		error_str = (char*)malloc(strlen(time_stamp)+ strlen(db_error_mess)+2);
-		sprintf ( error_str, "%s %s", time_stamp, db_error_mess );
+		error_str = (char*)malloc(strlen(time_stamp)+ strlen(db_error_mess)+3);
+		sprintf ( error_str, "%s  %s", time_stamp, db_error_mess );
 		/*return (DS_NOTOK);*/
 		return (error_str);
 	}
@@ -2082,8 +2112,8 @@ static char *get_error_string (long error)
  */
 	if ( ret_str == NULL )
 	{
-		error_str = (char*)malloc(strlen(time_stamp)+strlen(no_error_mess)+2);
-                sprintf ( error_str, "%s %s", time_stamp, no_error_mess );
+		error_str = (char*)malloc(strlen(time_stamp)+strlen(no_error_mess)+3);
+                sprintf ( error_str, "%s  %s", time_stamp, no_error_mess );
 		/*sprintf ( error_str, 
 		    "%s No error message stored in the database for error (%d/%d/%d)", 
 		    time_stamp, team, server, error_ident );*/
@@ -2094,8 +2124,8 @@ static char *get_error_string (long error)
  * Found the error string in the database. Return the string with 
  * a time stamp.
  */
-	error_str = (char*)malloc(strlen(time_stamp)+strlen(ret_str)+2);
-	sprintf ( error_str, "%s %s", time_stamp, ret_str );
+	error_str = (char*)malloc(strlen(time_stamp)+strlen(ret_str)+3);
+	sprintf ( error_str, "%s  %s", time_stamp, ret_str );
 	free (ret_str);
 	return (error_str);
 }
