@@ -1,5 +1,5 @@
 static char RcsId[]      =
-"@(#)$Header: oic.c,v 8.18 2000/11/12 13:24:03 goetz Rel $";
+"@(#)$Header: oic.c,v 8.30 2001/11/12 09:59:59 goetz Rel $";
 /*+*******************************************************************
 
  File:		oic.c
@@ -14,15 +14,51 @@ static char RcsId[]      =
 
  Original:	July 1995
 
- $Revision: 8.18 $
- $Date: 2000/11/12 13:24:03 $
+ $Revision: 8.30 $
+ $Date: 2001/11/12 09:59:59 $
 
  $Author: goetz $
 
  $Log:	oic.c,v $
- * Revision 8.18  2000/11/12  13:24:03  13:24:03  goetz (Andy Goetz)
- * added dynamic error handling; improved TANGO error treatment
+ * Revision 8.30  2001/11/12  09:59:59  09:59:59  goetz (Andy Goetz)
+ * updated C port for Windows 95/98/NT using Visual C++ 6
  * 
+ Revision 8.29  2001/07/26 05:05:09  goetz
+ fixed error in CORBA::is_nil() test
+
+ Revision 8.28  2001/07/25 13:13:15  goetz
+ tango cmd_query in_name and out_name left NULL; desc replaces reason for errors
+
+ Revision 8.27  2001/07/25 13:05:39  goetz
+ added space to dev_error_str() string; test CORBA::is_nil() for tango database
+
+ Revision 8.26  2001/04/10 14:24:34  goetz
+ set timeout on tango devices to 3 seconds
+
+ Revision 8.25  2001/03/20 11:56:39  goetz
+ DevCmdNameList searched before database for commands in tango_api.cpp
+
+ Revision 8.24  2001/03/10 16:38:20  goetz
+ ported tango_api to TANGO 2
+
+ Revision 8.23  2001/02/28 12:26:48  goetz
+ converted TANGO states to TACO states
+
+ Revision 8.22  2001/01/16 10:09:45  goetz
+ applied J.Quick's patch for security; removed stderr from DevServerMain.c
+
+ * Revision 8.21  2001/01/15  11:36:40  11:36:40  goetz (Andy Goetz)
+ * added check for ds == NULL in all dev_ api routines; changed ds__signal prototype
+ * 
+ Revision 8.20  2001/01/08 13:14:49  goetz
+ added patch by B.Pedersen to support querying events
+
+ Revision 8.19  2000/12/11 12:06:44  goetz
+ fixed bugs with TANGO interface returning unsigned values and states
+
+ Revision 8.18  2000/11/12 13:24:03  goetz
+ added dynamic error handling; improved TANGO error treatment
+
  Revision 8.17  1900/09/26 13:36:33  goetz
  tango_dev_putget() and tango_dev_putget_raw() implement immediate reconnection
 
