@@ -1,5 +1,5 @@
 static char RcsId[] = 
-"@(#)$Header: util_api.c,v 8.20 2001/01/08 12:05:09 goetz Rel $";
+"@(#)$Header: util_api.c,v 8.30 2001/11/12 09:59:58 goetz Rel $";
 
 /*+*******************************************************************
 
@@ -16,15 +16,45 @@ static char RcsId[] =
 
  Original   :	April 1993
 
- $Revision: 8.20 $
- $Date: 2001/01/08 12:05:09 $
+ $Revision: 8.30 $
+ $Date: 2001/11/12 09:59:58 $
 
  $Author: goetz $
 
  $Log:	util_api.c,v $
- * Revision 8.20  2001/01/08  12:05:09  12:05:09  goetz (Andy Goetz)
- * added patch by B.Pedersen to support querying events
+ * Revision 8.30  2001/11/12  09:59:58  09:59:58  goetz (Andy Goetz)
+ * updated C port for Windows 95/98/NT using Visual C++ 6
  * 
+ Revision 8.29  2001/07/26 05:05:07  goetz
+ fixed error in CORBA::is_nil() test
+
+ Revision 8.28  2001/07/25 13:13:14  goetz
+ tango cmd_query in_name and out_name left NULL; desc replaces reason for errors
+
+ Revision 8.27  2001/07/25 13:05:38  goetz
+ added space to dev_error_str() string; test CORBA::is_nil() for tango database
+
+ Revision 8.26  2001/04/10 14:24:33  goetz
+ set timeout on tango devices to 3 seconds
+
+ Revision 8.25  2001/03/20 11:56:37  goetz
+ DevCmdNameList searched before database for commands in tango_api.cpp
+
+ Revision 8.24  2001/03/10 16:38:18  goetz
+ ported tango_api to TANGO 2
+
+ Revision 8.23  2001/02/28 12:26:46  goetz
+ converted TANGO states to TACO states
+
+ Revision 8.22  2001/01/16 10:09:44  goetz
+ applied J.Quick's patch for security; removed stderr from DevServerMain.c
+
+ * Revision 8.21  2001/01/15  11:36:36  11:36:36  goetz (Andy Goetz)
+ * added check for ds == NULL in all dev_ api routines; changed ds__signal prototype
+ * 
+ Revision 8.20  2001/01/08 12:05:09  goetz
+ added patch by B.Pedersen to support querying events
+
  Revision 8.31  2000/07/28 09:59:53  dserver
  BP: added dev_query_event to get event parameters
      -> new data struture  for event list in server
@@ -339,6 +369,11 @@ long _DLLFunc dev_putget_raw (devserver ds, long cmd, DevArgument argin,
 	    "\ndev_putget_raw() : entering routine\n");
 #endif /* EBUG */
 
+	if (ds == NULL)
+	{
+		*error = DevErr_DeviceNotImportedYet;
+		return(DS_NOTOK);
+	}
 	if (dev_error_string != NULL)
 	{
 		free(dev_error_string);
@@ -504,6 +539,11 @@ long _DLLFunc dev_put_asyn (devserver ds, long cmd, DevArgument argin,
 	    "\ndev_put_asyn() : entering routine\n");
 #endif /* EBUG */
 
+	if (ds == NULL)
+	{
+		*error = DevErr_DeviceNotImportedYet;
+		return(DS_NOTOK);
+	}
 #ifdef TANGO
 	if (ds->rpc_protocol == D_IIOP)
 	{
@@ -651,6 +691,11 @@ long _DLLFunc dev_cmd_query (devserver ds, DevVarCmdArray *varcmdarr, long *erro
 	    "\ndev_cmd_query() : entering routine\n");
 #endif /* EBUG */
 
+	if (ds == NULL)
+	{
+		*error = DevErr_DeviceNotImportedYet;
+		return(DS_NOTOK);
+	}
 #ifdef TANGO
 	if (ds->rpc_protocol == D_IIOP)
 	{
@@ -1006,6 +1051,11 @@ long _DLLFunc dev_inform (devserver *clnt_handles, long num_devices,
 	    "\ndev_inform() : entering routine\n");
 #endif /* EBUG */
 
+	if (clnt_handles == NULL)
+	{
+		*error = DevErr_DeviceNotImportedYet;
+		return(DS_NOTOK);
+	}
 /*
  * Allocate memory for the array of information structures
  * only if the pointer "dev_info" is initialised to NULL.
@@ -1082,6 +1132,11 @@ long _DLLFunc dev_rpc_timeout (devserver ds, long request,
 {
 	*error = 0;
 
+	if (ds == NULL)
+	{
+		*error = DevErr_DeviceNotImportedYet;
+		return(DS_NOTOK);
+	}
 #ifdef TANGO
 	if (ds->rpc_protocol == D_IIOP)
 	{
@@ -1506,6 +1561,11 @@ long _DLLFunc dev_ping (devserver ds, long *error)
 	    "\ndev_ping() : entering routine\n");
 #endif /* EBUG */
 
+	if (ds == NULL)
+	{
+		*error = DevErr_DeviceNotImportedYet;
+		return(DS_NOTOK);
+	}
 #ifdef TANGO
         if (ds->rpc_protocol == D_IIOP)
         {
