@@ -14,12 +14,15 @@
  Original:	June 1991
 
 
- $Revision: 4.33 $
- $Date: 2001/01/10 10:20:18 $
+ $Revision: 4.34 $
+ $Date: 2001/03/21 18:44:22 $
 
  $Author: goetz $
 
  $Log: DevCmds.h,v $
+ Revision 4.34  2001/03/21 18:44:22  goetz
+ added DevCmdNameListEntry typedef for dev_cmds.c
+
  Revision 4.33  2001/01/10 10:20:18  goetz
  added B.Perdersen's patch to query events
 
@@ -131,7 +134,7 @@
  */
 #ifdef _IDENT
 static char DevCmdsh[] = 
-"@(#)$Header: /segfs/dserver/system/api/cmds_err/include/RCS/DevCmds.h,v 4.33 2001/01/10 10:20:18 goetz Exp $";
+"@(#)$Header: /segfs/dserver/dev/system/api/cmds_err/include/RCS/DevCmds.h,v 4.34 2001/03/21 18:44:22 goetz Exp $";
 #endif /* _IDENT */
 
 
@@ -822,6 +825,14 @@ typedef struct _DevEventListEntry {
                DevEventListEntry;
 
 typedef struct _DevEventListEntry *DevEventList;    
-#endif /* FORTRAN */
 
+/* for global command table */
+typedef struct _DevCmdNameListEntry {
+                                     int value;
+				     char *name;
+				     }
+               DevCmdNameListEntry;
+
+#endif /* FORTRAN */
 #endif /* _DevCmds_h */
+
