@@ -1,12 +1,6 @@
-static char RcsId[] = "@(#)$Header: /segfs/dserver/system/dc/svc/RCS/dc_devall.c,v 3.21 2000/12/03 07:19:13 goetz Rel goetz $";
+static char RcsId[] = "@(#)$Header: dc_devall.c,v 3.19 99/07/05 14:23:28 taurel Rel $";
 
-/* $Log: dc_devall.c,v $
- * Revision 3.21  2000/12/03 07:19:13  goetz
- * ported to Linux
- *
- * Revision 3.20  2000/03/13 15:28:26  taurel
- * Adapted to the new release of gettranscient (DSAIPI release 7.8 and above)
- *
+/* $Log:	dc_devall.c,v $
  * Revision 3.19  99/07/05  14:23:28  14:23:28  taurel (E.Taurel)
  * Porte dto new release of gettranscienr_ut. I don't understand how it worked
  * before !!
