@@ -1,12 +1,6 @@
-static char RcsId[] = "@(#)$Header: /segfs/dserver/system/dc/svc/RCS/dcrd_svc.c,v 3.21 2000/12/03 07:19:13 goetz Rel goetz $";
+static char RcsId[] = "@(#)$Header: dcrd_svc.c,v 3.19 99/07/05 14:24:25 taurel Rel $";
 
-/* $Log: dcrd_svc.c,v $
- * Revision 3.21  2000/12/03 07:19:13  goetz
- * ported to Linux
- *
- * Revision 3.20  2000/03/13 15:28:33  taurel
- * Adapted to the new release of gettranscient (DSAIPI release 7.8 and above)
- *
+/* $Log:	dcrd_svc.c,v $
  * Revision 3.19  99/07/05  14:24:25  14:24:25  taurel (E.Taurel)
  * Porte dto new release of gettranscienr_ut. I don't understand how it worked
  * before !!
@@ -244,9 +238,6 @@ char *argv[];
 	int sig_mask;
 	struct sigvec sighand;
 #endif
-#ifdef linux
-	struct sigaction sigact;
-#endif /* linux */
 
 /* Added variables to manage transient program number */
 
@@ -301,7 +292,6 @@ char *argv[];
 	sigvec(SIGXCPU,&sighand,NULL);
 	sigvec(SIGXFSZ,&sighand,NULL);
 #else
-#ifndef linux
 	(void) sigignore(SIGHUP);
 	(void) sigset(SIGINT, un_register_prog);
 	(void) sigset(SIGQUIT, un_register_prog);
@@ -313,28 +303,6 @@ char *argv[];
 	(void) sigset(SIGVTALRM, default_sig);
 	(void) sigset(SIGPROF, default_sig);
 	(void) sigset(SIGLOST, default_sig);
-#else
-	sigact.sa_handler = SIG_IGN;
-	sigaction(SIGHUP, &sigact, NULL);
-	sigact.sa_handler = un_register_prog;
-	sigaction(SIGINT, &sigact, NULL);
-	sigact.sa_handler = un_register_prog;
-	sigaction(SIGQUIT, &sigact, NULL);
-	sigact.sa_handler = un_register_prog;
-	sigaction(SIGTERM, &sigact, NULL);
-	sigact.sa_handler = time_out_prog;
-	sigaction(SIGALRM, &sigact, NULL);
-	sigact.sa_handler = default_sig;
-	sigaction(SIGPIPE, &sigact, NULL);
-	sigact.sa_handler = default_sig;
-	sigaction(SIGUSR1, &sigact, NULL);
-	sigact.sa_handler = default_sig;
-	sigaction(SIGUSR2, &sigact, NULL);
-	sigact.sa_handler = default_sig;
-	sigaction(SIGVTALRM, &sigact, NULL);
-	sigact.sa_handler = default_sig;
-	sigaction(SIGPROF, &sigact, NULL);
-#endif /* !linux */
 #endif /* sun */
 
 /* Change max number of open files to 120 */
@@ -360,7 +328,7 @@ char *argv[];
 	strcat(full_name,"/");
 	strcat(full_name,argv[1]);
 	
-	pgnum = gettransient(full_name);
+	pgnum = gettransient_ut(full_name,&sock_udp,&sock_tcp);
 
 	if (pgnum == 0)
 	{
@@ -373,6 +341,11 @@ char *argv[];
 	printf("Program number : %x in hexa or %d in decimal\n",pgnum,pgnum);
 #endif /* DEBUG */
 
+#ifdef _solaris
+	close(sock_tcp);
+	sock_tcp = RPC_ANYSOCK;
+	pmap_unset(pgnum,DC_VERS);
+#endif /* _solaris */
 
 	transp_tcp = svctcp_create(sock_tcp,0,0);
 
@@ -390,6 +363,11 @@ char *argv[];
 		leave(NO_UNREG);
 	}
 
+#ifdef _solaris
+	close(sock_udp);
+	sock_udp = RPC_ANYSOCK;
+#endif /* _solaris */
+
 	transp_udp = svcudp_create(sock_udp);
 	if (transp_udp == NULL)
 	{
@@ -521,7 +499,7 @@ dc_prog_1(rqstp, transp)
 	switch (rqstp->rq_proc)
 	{
 	case NULLPROC:
-		svc_sendreply(transp, (const xdrproc_t)xdr_void, NULL);
+		svc_sendreply(transp, xdr_void, NULL);
 		return;
 
 	case DC_DEVGET:
@@ -556,11 +534,11 @@ dc_prog_1(rqstp, transp)
 
 	case RPC_CHECK:
 		tmp_ch = ds_name;
-		svc_sendreply(transp,(const xdrproc_t)xdr_wrapstring,(caddr_t)&tmp_ch);
+		svc_sendreply(transp,xdr_wrapstring,(caddr_t)&tmp_ch);
 		return;
 		
 	case RPC_QUIT_SERVER:
-		svc_sendreply(transp,(const xdrproc_t)xdr_void,NULL);
+		svc_sendreply(transp,xdr_void,NULL);
 		pid = getpid();
 		kill(pid,SIGQUIT);
 		return;
@@ -572,17 +550,17 @@ dc_prog_1(rqstp, transp)
 
 	memset(&argument, 0, sizeof(argument));
 
-	if (!svc_getargs(transp, (const xdrproc_t)xdr_argument, (caddr_t)&argument))
+	if (!svc_getargs(transp, xdr_argument, (caddr_t)&argument))
 	{
 		svcerr_decode(transp);
 		return;
 	}
 	result = (*local)(&argument, rqstp);
-	if (result != NULL && !svc_sendreply(transp, (const xdrproc_t)xdr_result, result))
+	if (result != NULL && !svc_sendreply(transp, xdr_result, result))
 	{
 		svcerr_systemerr(transp);
 	}
-	if (!svc_freeargs(transp, (const xdrproc_t)xdr_argument, (caddr_t)&argument))
+	if (!svc_freeargs(transp, xdr_argument, (caddr_t)&argument))
 	{
 		fprintf(stderr, "unable to free arguments\n");
 		exit(1);
