@@ -1,5 +1,5 @@
 static char RcsId[] =
-"@(#)$Header: ManagerMain.c,v 4.12 2000/03/15 17:23:22 taurel Rel $ ";
+"@(#)$Header: ManagerMain.c,v 4.12 20/0./3. 5.:7.:3. taurel Rel $ ";
 /********************************************************************
 
  File:          ManagerMain.c
@@ -16,12 +16,12 @@ static char RcsId[] =
 
 
  $Revision: 4.12 $
- $Date: 2000/03/15 17:23:22 $
+ $Date: 20/0./3. 5.:7.:3. $
 
  $Author: taurel $
 
  $Log:	ManagerMain.c,v $
- * Revision 4.12  2000/03/15  17:23:22  17:23:22  taurel (E.Taurel)
+ * Revision 4.12  20/0./3.  5.:7.:3.  5.:7.:3.  taurel (E.Taurel)
  * Remove the chmod for unix operating system
  * 
  * Revision 4.11  99/11/21  20:36:15  20:36:15  goetz (Andy Goetz)
@@ -217,7 +217,7 @@ main (argc,argv)
 #endif /* solaris */
 #endif /* sun */
 
-#ifdef hpux10
+#ifdef __hpux
 	sprintf (homepath, "%s/system/bin/hpux10.2", dshome);
 #endif /* hpux10 */
 
