@@ -13,12 +13,15 @@
  Original:	January 1991
 
 
-$Revision: 5.20 $
-$Date: 2001/01/08 12:17:37 $
+$Revision: 5.21 $
+$Date: 2001/11/12 10:01:38 $
 
 $Author: goetz $
 
-$Log: API_xdr.h,v $
+$Log:	API_xdr.h,v $
+ * Revision 5.21  2001/11/12  10:01:38  10:01:38  goetz (Andy Goetz)
+ * updated C port for Windows 95/98/NT using Visual C++ 6
+ * 
 Revision 5.20  2001/01/08 12:17:37  goetz
 added patch by B.Pedersen to support querying events
 
@@ -208,7 +211,7 @@ Check
  */
 #ifdef _IDENT
 static char API_xdrh[] =
-"@(#)$Header: /segfs/dserver/system/xdr/include/RCS/API_xdr.h,v 5.20 2001/01/08 12:17:37 goetz Rel $";
+"@(#)$Header: API_xdr.h,v 5.21 2001/11/12 10:01:38 goetz Rel $";
 #endif /* _IDENT */
 
 
