@@ -15,12 +15,15 @@
  Original:	November 1993
 
 
- $Revision: 5.20 $
- $Date: 2001/01/08 12:17:37 $
+ $Revision: 5.21 $
+ $Date: 2001/11/12 10:01:38 $
 
  $Author: goetz $
 
- $Log: DevXdrKernel.h,v $
+ $Log:	DevXdrKernel.h,v $
+ * Revision 5.21  2001/11/12  10:01:38  10:01:38  goetz (Andy Goetz)
+ * updated C port for Windows 95/98/NT using Visual C++ 6
+ * 
  Revision 5.20  2001/01/08 12:17:37  goetz
  added patch by B.Pedersen to support querying events
 
@@ -171,7 +174,7 @@
  */
 #ifdef _IDENT
 static char DevXdrKernelh[] =
-"@(#)$Header: /segfs/dserver/system/xdr/include/RCS/DevXdrKernel.h,v 5.20 2001/01/08 12:17:37 goetz Rel $";
+"@(#)$Header: DevXdrKernel.h,v 5.21 2001/11/12 10:01:38 goetz Rel $";
 #endif /* _IDENT */
 
 
