@@ -12,12 +12,15 @@
  Original:      July 1994
 
 
- $Revision: 5.21 $
- $Date: 2001/01/08 12:17:37 $
+ $Revision: 5.22 $
+ $Date: 2001/11/12 10:01:38 $
 
  $Author: goetz $
 
- $Log: macros.h,v $
+ $Log:	macros.h,v $
+ * Revision 5.22  2001/11/12  10:01:38  10:01:38  goetz (Andy Goetz)
+ * updated C port for Windows 95/98/NT using Visual C++ 6
+ * 
  Revision 5.21  2001/01/08 12:17:37  goetz
  added patch by B.Pedersen to support querying events
 
@@ -153,7 +156,7 @@
 
 #if !defined(FORTRAN)
 
-#if defined (_NT) && defined (_WIN32)
+#if defined (WIN32)
 #undef __STDC__
 #include <stdio.h>
 #include <time.h>
@@ -163,7 +166,7 @@
 #include <string.h>
 #include <ctype.h>
 #include <winsock.h>
-#include <nm_rpc.h>
+#include <rpc/rpc.h>
 #include <process.h>
 
 /*
@@ -291,7 +294,7 @@ typedef unsigned int	size_t;
 #define PRINTF(a)      printf(a)
 
 #else /* (_NT) */
-#define _LPfd_set	LPfd_set
+#define _LPfd_set	struct fd_set *
 #define	_Int		short
 #define _WINAPI     WINAPI	   /* needed for MSVC++ */
 #define TIMEVAL(a)    (struct timeval*)&a	  /* needed for NetManage's RPC clnt_call() */
