@@ -1,6 +1,6 @@
 
 static char RcsId[] =
-"@(#)$Header: /segfs/dserver/system/xdr/src/RCS/api_xdr_vers3.c,v 5.20 2001/01/08 12:17:35 goetz Rel $";
+"@(#)$Header: api_xdr_vers3.c,v 5.21 2001/11/12 10:01:36 goetz Rel $";
 /*+*******************************************************************
 
  File:          api_xdr_vers3.c
@@ -16,12 +16,15 @@ static char RcsId[] =
  Original:      November 1994
 
 
-$Revision: 5.20 $
-$Date: 2001/01/08 12:17:35 $
+$Revision: 5.21 $
+$Date: 2001/11/12 10:01:36 $
 
 $Author: goetz $
 
-$Log: api_xdr_vers3.c,v $
+$Log:	api_xdr_vers3.c,v $
+ * Revision 5.21  2001/11/12  10:01:36  10:01:36  goetz (Andy Goetz)
+ * updated C port for Windows 95/98/NT using Visual C++ 6
+ * 
 Revision 5.20  2001/01/08 12:17:35  goetz
 added patch by B.Pedersen to support querying events
 
