@@ -6,7 +6,10 @@
  Author(s):     Timo Mettala
  Original:      March  1993
 
-$Log: icv101_xdr.c,v $
+$Log:	icv101_xdr.c,v $
+ * Revision 5.21  2001/11/12  10:01:36  10:01:36  goetz (Andy Goetz)
+ * updated C port for Windows 95/98/NT using Visual C++ 6
+ * 
 Revision 5.20  2001/01/08 12:17:35  goetz
 added patch by B.Pedersen to support querying events
 
@@ -146,7 +149,7 @@ Copyright (c) 1993 by European Synchrotron Radiation Facility,
 *******************************************************************-*/
 
 static char RcsId[] =
-"$Header: /segfs/dserver/system/xdr/src/RCS/icv101_xdr.c,v 5.20 2001/01/08 12:17:35 goetz Rel $";
+"$Header: icv101_xdr.c,v 5.21 2001/11/12 10:01:36 goetz Rel $";
 
 #include "dev_xdr.h"
 #include "icv101_xdr.h"
