@@ -1,5 +1,5 @@
 static char RcsId[] =
-"$Header: /segfs/dserver/system/xdr/src/RCS/slit_xdr.c,v 5.20 2001/01/08 12:17:35 goetz Rel $";
+"$Header: slit_xdr.c,v 5.21 2001/11/12 10:01:36 goetz Rel $";
 
 /*+*******************************************************************
 
@@ -13,7 +13,10 @@ static char RcsId[] =
 
  Original:      September 1992
 
-$Log: slit_xdr.c,v $
+$Log:	slit_xdr.c,v $
+ * Revision 5.21  2001/11/12  10:01:36  10:01:36  goetz (Andy Goetz)
+ * updated C port for Windows 95/98/NT using Visual C++ 6
+ * 
 Revision 5.20  2001/01/08 12:17:35  goetz
 added patch by B.Pedersen to support querying events
 
